from rocolib.api.components.Component import Component
from rocolib.api.Function import Function

c = Component()

c.addSubcomponent("leftArm", "Rectangle")
c.addSubcomponent("rightArm", "Rectangle")
c.addSubcomponent("dcMount", "SimpleRectBeam")

c.addParameter("motorWidth", 8, parameterType="length")
c.addParameter("motorHeight", 8, parameterType="length")
c.addParameter("mountWidth", 40, parameterType="length") # = boat width
c.addParameter("supportLength", 60, parameterType="length") # = boat depth

c.addSubcomponent("cutout1", "Cutout")
c.addSubcomponent("cutout2", "Cutout")

c.addConstraint(("cutout1", "dx"), "motorWidth")
c.addConstraint(("cutout1", "dy"), "motorHeight")

c.addConstraint(("cutout2", "dx"), "motorWidth")
c.addConstraint(("cutout2", "dy"), "motorHeight")

c.addConnection(("dcMount", "face0"),
                   ("cutout1", "decoration"),
                   mode="hole", offset=Function(params=("motorWidth"), fnstring="(-10, 0)"))

c.addConnection(("dcMount", "face2"),
                   ("cutout2", "decoration"),
                   mode="hole", offset=Function(params=("motorWidth"), fnstring="(10, 0)"))

c.addConstConstraint(("leftArm", "w"), 10)
c.addConstraint(("leftArm", "l"), "mountWidth") #DEPTH OF BOAT - 3 for the tab

c.addConstConstraint(("rightArm", "w"), 10)
c.addConstraint(("rightArm", "l"), "mountWidth") #DEPTH OF BOAT

c.addConstraint(("dcMount", "length"), "mountWidth") #boat width
c.addConstConstraint(("dcMount", "width"), 30)
c.addConstConstraint(("dcMount", "depth"), 10)

c.join(("dcMount", "topedge1"), ("leftArm", "r")) #l/r, not t/b
c.join(("dcMount", "botedge1"), ("rightArm", "r"))

c.inheritInterface("leftArmInterface", ("leftArm", "l"))
c.inheritInterface("rightArmInterface", ("rightArm", "l"))

c.toLibrary("DCMotorMount")
